==> emodpy_covid-0.0.31-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_isolate_symptomatic_nosql.py <==
import json
from . import schema_to_class as s2c

"""
python3 -c 'import emodpy_covid.mid.dtk_in_process_isolate_symptomatic_nosql as iso; iso.isolate_detecteds_nosql(0);'
"""

def app( timestep ): 
    campaign = {}
    campaign["Events"] = []

    event = s2c.get_default_campaign_event()
    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics 

    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    event.Event_Coordinator_Config = coordinator
    intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV" )

    coordinator.Intervention_Config = intervention 
    coordinator.Intervention_Config.Trigger_Condition_List = [ "NewlySymptomatic", "NewSevereCase" ] 

    actual_intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    bcast_intervention.Broadcast_Event = "IsolateAtHome"

    actual_actual_intervention = s2c.get_class_with_defaults( "RouteAwareSimpleVaccine" )
    actual_actual_intervention.Vaccine_Type = "TransmissionBlocking"
    actual_actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_CONTACT"
    intervention.Actual_IndividualIntervention_Config = actual_intervention
    intervention.pop( "Actual_NodeIntervention_Config" )
    actual_intervention.Intervention_List = [ actual_actual_intervention, bcast_intervention ]

    waning = s2c.get_class_with_defaults( "WaningEffectBox" )
    actual_actual_intervention.Waning_Config = waning 
    waning.Initial_Effect = 0.95
    waning.Box_Duration = 14

    campaign["Events"].append( event )

    # Make infected people 50% less infectious at home coz they know they're sick and try to isolate
    event = s2c.get_default_campaign_event()
    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics 
    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" )
    intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV" )
    actual_intervention = s2c.get_class_with_defaults( "RouteAwareSimpleVaccine" )

    event = s2c.get_default_campaign_event()
    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics 
    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    coordinator.Intervention_Config.Trigger_Condition_List = [ "NewlySymptomatic", "NewSevereCase" ] 
    actual_intervention.Vaccine_Type = "TransmissionBlocking"
    actual_intervention.Vaccine_Route = "TRANSMISSIONROUTE_ENVIRONMENTAL"
    intervention.Actual_IndividualIntervention_Config = actual_intervention
    intervention.pop( "Actual_NodeIntervention_Config" )
    waning.Initial_Effect = 0.5
    actual_intervention.Waning_Config = waning 

    campaign["Events"].append( event )

    new_camp_filename = "isolate_infected.json"
    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file )
    return new_camp_filename

==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/mid/dtk_in_process_isolate_symptomatic_nosql.py <==
import json
import copy
from . import schema_to_class as s2c

"""
python3 -c 'import emodpy_covid.mid.dtk_in_process_isolate_symptomatic_nosql as iso; iso.isolate_detecteds_nosql(0);'
"""

efficacy = 0.95
duration = 14
home_suppression_effect = 0.5
debug = False

def get_event( timestep, route, efficacy, intervention_name ):
    event = s2c.get_default_campaign_event()

    coordinator = s2c.get_class_with_defaults( "StandardEventCoordinator" )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 

    intervention = s2c.get_class_with_defaults( "NodeLevelHealthTriggeredIV" )

    actual_intervention = s2c.get_class_with_defaults( "MultiInterventionDistributor" ) 
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent" ) 
    actual_actual_intervention = s2c.get_class_with_defaults( "RouteAwareSimpleVaccine" )
    waning = s2c.get_class_with_defaults( "WaningEffectBox" )

    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention 
    intervention.Actual_IndividualIntervention_Config = actual_intervention
    actual_actual_intervention.Waning_Config = waning 

    event.Start_Day = float(timestep) # set from sweep, then by query for number of symptomatics 
    coordinator.Intervention_Config.Trigger_Condition_List = [ "NewlySymptomatic", "NewSevereCase" ] 
    bcast_intervention.Broadcast_Event = "IsolateAtHome" 
    actual_actual_intervention.Vaccine_Type = "TransmissionBlocking"
    actual_actual_intervention.Vaccine_Route = route
    actual_actual_intervention.Intervention_Name = intervention_name
    actual_actual_intervention.Duplicate_Policy = "Replace"
    intervention.pop( "Actual_NodeIntervention_Config" )
    actual_intervention.Intervention_List = [ actual_actual_intervention, bcast_intervention ]

    waning.Initial_Effect = efficacy
    waning.Box_Duration = duration

    coordinator.finalize()
    intervention.finalize()
    actual_intervention.finalize()
    actual_actual_intervention.finalize()
    bcast_intervention.finalize()
    waning.finalize()
    return event

def app( timestep ): 
    campaign = {}
    campaign["Events"] = []

    campaign["Events"].append( get_event( timestep, "TRANSMISSIONROUTE_CONTACT", efficacy, "IsolateAtHome" ) )
    campaign["Events"].append( get_event( timestep, "TRANSMISSIONROUTE_ENVIRONMENTAL", home_suppression_effect, "AndDontInfectYourFamily" ) ) 

    new_camp_filename = "isolate_infected"
    if debug:
        new_camp_filename += "_" + str(timestep)
    new_camp_filename += ".json"
    with open( new_camp_filename, "w" ) as camp_file:
        json.dump( campaign, camp_file, sort_keys=True, indent=4 )
    return new_camp_filename
